API Reference
=============

Core Classes
------------

.. autoclass:: amgd.models.PoissonRegressor
    :members:

.. autoclass:: amgd.core.optimizers.AMGDOptimizer
    :members:

.. autoclass:: amgd.models.GLM
    :members: